from pagerduty_events_api.pagerduty_rest_client import PagerdutyRestClient


class PagerdutyIncident:
    def __init__(self, service_key, incident_key):
        self.__service_key = service_key
        self.__incident_key = incident_key

    def get_service_key(self):
        return self.__service_key

    def get_incident_key(self):
        return self.__incident_key

    def acknowledge(self):
        self.__send_request_with_event_type('acknowledge')

    def resolve(self):
        self.__send_request_with_event_type('resolve')

    def __send_request_with_event_type(self, event_type):
        payload = {'service_key': self.__service_key,
                   'event_type': event_type,
                   'incident_key': self.__incident_key}

        PagerdutyRestClient().post(payload)



from pagerduty_events_api.pagerduty_incident import PagerdutyIncident
from pagerduty_events_api.pagerduty_service import PagerdutyService

from pagerduty_events_api.pagerduty_rest_client import PagerdutyBadRequestException
from pagerduty_events_api.pagerduty_rest_client import PagerdutyForbiddenException
from pagerduty_events_api.pagerduty_rest_client import PagerdutyNotFoundException
from pagerduty_events_api.pagerduty_rest_client import PagerdutyServerErrorException



from setuptools import setup

setup(name='pagerduty_events_api',
      version='0.1.1',
      description='Python wrapper for Pagerduty Events API',
      url='https://github.com/BlasiusVonSzerencsi/pagerduty-events-api',
      download_url='https://github.com/BlasiusVonSzerencsi/pagerduty-events-api/tarball/0.1.1',
      author='Balazs Szerencsi',
      author_email='balazs.szerencsi@icloud.com',
      license='MIT',
      packages=['pagerduty_events_api'],
      zip_safe=False,
      test_suite='nose.collector',
      tests_require=['nose', 'ddt'],
      install_requires=['requests'],
      keywords=['pagerduty', 'event', 'api', 'incident', 'trigger', 'acknowledge', 'resolve'])



from pagerduty_events_api.pagerduty_incident import PagerdutyIncident
from pagerduty_events_api.pagerduty_rest_client import PagerdutyRestClient


class PagerdutyService:
    def __init__(self, key):
        self.__service_key = key

    def get_service_key(self):
        return self.__service_key

    def trigger(self, description):
        payload = {'service_key': self.__service_key,
                   'event_type': 'trigger',
                   'description': description}

        incident_data = PagerdutyRestClient().post(payload)

        return PagerdutyIncident(self.__service_key, incident_data['incident_key'])
